@@ -10,17 +10,20 @@ class TestNormalizedDependentDistribution(unittest.TestCase):
             "b": 3,
             "c": 2
         }
-        with self.assertLogs('conflowgen', level='DEBUG') as cm:
-            normalized_distribution = normalize_distribution_with_no_dependent_variable(distribution)
+        with self.assertLogs('conflowgen', level='DEBUG') as context:
+            normalized_distribution = normalize_distribution_with_no_dependent_variable(
+                distribution,
+                values_are_frequencies=True
+            )
         self.assertDictEqual(
             normalized_distribution, {
                 "b": 0.6,
                 "c": 0.4
             }
         )
-        self.assertEqual(len(cm.output), 1, "Excatly one log message")
+        self.assertEqual(len(context.output), 1, "Exactly one log message")
         self.assertEqual(
-            cm.output[0],
+            context.output[0],
             "DEBUG:conflowgen:Sum of fractions was not 1 and was automatically normalized."
         )
 
@@ -29,5 +32,8 @@ class TestNormalizedDependentDistribution(unittest.TestCase):
             "b": 0.6,
             "c": 0.4
         }
-        normalized_distribution = normalize_distribution_with_no_dependent_variable(distribution)
+        normalized_distribution = normalize_distribution_with_no_dependent_variable(
+            distribution,
+            values_are_frequencies=True
+        )
         self.assertDictEqual(distribution, normalized_distribution)
